#
# spec file for package ugrep
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?amzn}
%bcond_with fish
%else
%bcond_without fish
%endif
Name:           ugrep
Version:        7.4.3
Release:        1.1
Summary:        Universal grep: a feature-rich grep implementation with focus on speed
License:        BSD-3-Clause
Group:          Productivity/File utilities
URL:            https://github.com/Genivia/ugrep
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(bzip3)
BuildRequires:  pkgconfig(libbrotlidec)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(zlib)
Provides:       ugrep-indexer = 1.0.0
Obsoletes:      ugrep-indexer < 1.0.0

%description
Ugrep supports an interactive query UI and can search file systems, source
code, text, binary files, archives, compressed files, documents and use
fuzzy search.

%package bash-completion
Summary:        Bash completion for ugrep
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion

This package contains the bash completion for ugrep.

%package zsh-completion
Summary:        Zsh completion for ugrep
BuildRequires:  zsh
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion

This package contains the zsh completion for ugrep.

%if %{with fish}
%package fish-completion
Summary:        Fish completion for ugrep
BuildRequires:  fish
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion

This package contains the fish completion for ugrep.
%endif

%prep
%autosetup -p1

%build
%configure \
	--disable-avx2 \
	--enable-color \
	--with-bzip3 \
%if !%{with fish}
	--with-fish-completion-dir=no \
%endif
	%{nil}
%make_build

%install
%make_install
%fdupes %{buildroot}%{_datadir}/%{name}

%check
%make_build test

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}
%{_datadir}/ugrep

%files bash-completion
%license LICENSE.txt
%{_datadir}/bash-completion/completions/*

%files zsh-completion
%license LICENSE.txt
%{_datadir}/zsh/site-functions/*

%if %{with fish}
%files fish-completion
%license LICENSE.txt
%{_datadir}/fish/vendor_completions.d/*.fish
%endif

%changelog
* Tue May 27 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.4.3:
  * fix bug in option -x and regex ^$-anchors used in certain short
    patterns
  * mark likely/unlikely branches for performance
* Wed Apr 30 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.4.2:
  * speed up regex pattern search for some more extreme cases
  * clean up code base to remove shadowed locals
  * add safeguards for preventable pattern undermatch
* Sun Apr 27 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.4.1:
  * more responsive output when searching slow standard input pipes
    such as tail -f log | ug pattern
  * new option argument -t seed7 (or --file-type=seed7) searches
    seed7 files
  * faster path glob search
  * options with paths (globs containing a /) also enable option
  - r when -d, -r or -R are not specified
  * clarify the usefulness of the default to not empty-match
    empty-matching patterns versus GNU grep that does
    (as with ugrep option -Y)
  * option -z (or --decompress) now also auto-detects bzip2, XZ,
    and Zstandard compressed files
  * new option --from=FILE: read additional pathnames of files to
    search from FILE
  * drain the input pipe until EOF when reading non-seekable
    standard input such as from a pipe, for compatibility with GNU
    grep
* Tue Mar  4 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.3.0:
  * make options -i (--ignore-case) and -j (--smart-case) respect
    Unicode letter case conventions
  * usability improvements
* Wed Feb  5 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.2.2:
  * improve search speed when the specified regex pattern is not
    found in the input when the specified regex starts with a
    wildcard such as .*, which previously resulted in unnecessary
    regex match processing overhead
* Tue Jan 28 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.2.1:
  * Fix possible hang when SIMD is not available for some options
    and patterns
* Fri Jan 24 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.2.0:
  * new options --no-files-with-matches and --no-count
  * update options -i and -j when used together: -i unconditional
    case-insensitive matching should override -j smart-case
    conditional case-insensitive matching
  * new adoc type added to option -t or --file-type
  * new full support for GNU/BSD grep option -z (--null-data),
    such that -z is reassigned from --decompress to --null-data
    when ugrep is specifically copied or symlinked with the target
    name grep, egrep, fgrep, zgrep, zegrep, or zfgrep executable
    file binaries to run as replacements of GNU/BSD grep
  * fix a bug in ugrep v7 when matching certain case-insensitive
    patterns at the very end of a file at EOF when an EOL before
    EOF is missing (this is not a problem in versions prior to v7)
* Sat Jan 11 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.1.3:
  * fix a problem with option -i (--ignore-case) that in rare and
    specific circumstances may not match all of the specified
    alternate sub-patterns
* Wed Jan  1 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.1.2:
  * support the latest bzip3 library upgrades
  * permit su search of "unreadable" files
  * do not exit with code 2 when some files can't be decompressed
- enable bzip3 support for Leap
* Thu Dec  5 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.1.1:
  * fix negative character classes when option -i or --ignore-case
    is used and make ugrep closely emulate GNU grep's character
    class behavior when options -i and -P are used
  * appease -Woverload-virtual and -Wshadow warnings
* Sat Nov 23 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.1.0:
  * add TUI glob editor syntax highlighting
  * bin/ug(|rep)+: Let the helper script work if no helper is
    available
* Sun Nov 17 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 7.0.4:
  * TUI fixes for other platforms
- remove Windows binaries from src rpm; switch to source service
* Tue Nov 12 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 7.0.3:
  * fixes for other platforms
  * usability improvements
* Mon Oct 28 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 7.0.2:
  * rewritten SIMD acceleration logic and the search algorithm
    selection decision logic to speed up pattern matching (the
    actual speedup depends on the type of regex patterns specified)
  * improved regex anchors and word boundary matching speed and
    support
  * fix option --xml pathnames with special characters, which are
    unlikely to occur in pathnames, but aren't strictly forbidden
  * updated option --hexdump with -ABC context hex lines before and
    after a match
  * the TUI now also uses the VISUAL environment variable if PAGER
    is not set
* Wed Oct  9 2024 jun wang <jgwang@suse.com>
- disable AVX2/AVX512BW CPU extensions because of bsc#1222752
* Sat Aug 24 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.5.0
  * faster binary file checking with SIMD (SSE2/AVX2/NEON) UTF-8
    validation
  * new option --context-separator=SEP
  * options -W and -X now also apply to --format fields %%o and %%O
    to output hex
  * ugrep-indexer option -z (indexes compressed files and
    zip/7z/tar/cpio/pax archives) no longer indexes hidden
    directories and files (i.e. "dotfiles") stored in archives, to
    save space
- make spec build on Amazon Linux 2023
* Fri Aug  9 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.4.1:
  * fix problem with --fixed-strings and --file FILE when FILE
    contains an \E
* Fri Aug  9 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.4.0:
  * new custom output format fields for options --format and
  - -replace
  * fix bash completions for key bindings
* Wed Jul 31 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.3.0:
  * option --index always enables --recursive
  * new bash, fish and zsh ugrep-indexer completions
  * option --hyperlink outputs absolute search paths
  * update regex DFA cut optimization that was too agressive for
    some patterns
  * option -o (--only-matching) with -ABC context now also
    supports multi-line pattern matching with \n (newline) in regex
    patterns
* Wed Jul 10 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.2.0:
  * improved support for legacy grep color environment variable
    single ANSI color codes format
  * improved zsh -ABC options completion
  * improved option -%% (--bool) when multiple -e PATTERN are
    specified; now aligns with the documentation of option -e to
    match any of the specified PATTERN (note that -%% can be
    combined with options --and, --andnot, --not. -e amd -N)
  * improved option -Q (--query) when combined with options --and,
  - -andnot, --not by activatating option -%% (--bool) so that the
    combined search patterns can be edited as one Boolean query
    pattern in the TUI
  * minor speed improvement when searching in large files with
    option -f with a file with hundreds, thousands or more
    words/strings to find (-fwords/4.txt in benchmarks)
  * again extensively tested with randomized patterns
* Tue Jun  4 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.1.0:
  * improve option -w to support Unicode
  * make [[:alpha:]] and other [::] character classes also match
    Unicode by default, like \p{Class} already does, unless option
  - U (--ascii or --binary) is used
  * Unicode word boundaries \<, \>, \b, \B unless option -U
    (--ascii or --binary) is used
  * improve bash and zsh auto-completion usability
* Tue May  7 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.0.0:
  * faster search speeds on ARM CPUs
  * overall optimization
  * includes ugrep-indexer
* Wed Apr 10 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 5.1.4:
  * use statfs() with options --include-fs and --exclude-fs when
    the preferred statvfs() is not available
  * suppress --filter utility stderr messages when ugrep options
  - s (--no-messages) and -q (--quiet) are used
  * support the NO_COLOR environment variable to suppress color
    output
  * fix TUI scroll glitch in non-split screen, and other TUI fixes
- enable SIMD code for faster matching on CPUs that support it
  (while keeping build reproducible)
* Mon Mar 11 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 5.1.1:
  * fix a problem with POSIX lazy quantifier matching when combined
    with anchors, causing longer pattern matches than expected
* Sat Mar  9 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 5.1.0:
  * a minor improvement of the regex syntax to allow escaped spaces
  * updated POSIX regex lazy quantifier matching in linear time
    using an advanced DFA transformation algorithm
* Sat Feb 17 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 5.0.0:
  * new and updated regex engine to speed up searching patterns
    using a new heuristic DFA cut algorithm
  * new option --exclude-fs default to exclude file systems that
    aren't specified as search targets
  * new option --all (-@) to search all files except hidden:
    cancel previous file and directory search restrictions
  * TUI regex syntax highlighting improved for --fixed-strings
    (-F) when used with option --bool (-%% and -%%%%)
* Wed Jan 10 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.5.2:
  * fix 7zip search failing on 32 bit systems when option -M is used
    (or -t when setting -M)
* Sat Jan  6 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.5.1:
  * fix bzip3 build failures (previously patched)
- drop ugrep-4.5.0-fix-bzip3-configure.patch
* Sat Jan  6 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.5.0:
  * 7zip archive search with option -z
  * apply Unicode normalization to canonicalize literal combining
    characters in regex patterns
  * improved TUI TAB directory navigation when searching from the FS
    root
- drop ugrep-4.4.1-remove-shebang-from-bash-completion.patch
- add ugrep-4.5.0-fix-bzip3-configure.patch
* Tue Dec 19 2023 Andreas Stieger <andreas.stieger@gmx.de>
- 4.4.1
  * ship shell completions (bash,zsh,fish)
  * option -t (--file-type) now also accepts filename extensions as
    shortcuts, when unambiguous, for example, the shorter form -tpy
    for -tpython to select files to search
  * TUI ALT-SHIFT-%% switches between "bool query lines" mode,
    "bool query files" mode, and bool queries off
    TUI boolF mode (-%%FQ) now applies syntax highlighting
  * support legacy grep long options without = to bind option
    arguments
- add ugrep-4.4.1-remove-shebang-from-bash-completion.patch
* Sat Dec  9 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.3.6:
  * fix an issue with option -Zbest fuzzy matching
  * updated option --index for accelerated index-based search, now
    also indexes and searches archives and compressed files with
    option -z
  * faster search with -ABC context options
* Sat Nov 25 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.3.4:
  * the ug command no longer quits with an error message when no
    default .ugrep config file was found
  * improved GNU grep compatibility
  * Bug fixes for parsing configuration files
* Wed Nov 15 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.3.3:
  * support brotli compressed files
  * support bzip3 compressed files
  * update option --pretty to accept an optional WHEN argument
    never, always, auto similar to the --color option
  * improve TUI screen blanking response when a new search starts,
    while also avoiding screen flicker
  * fix option --zmax>1 when a decompression library produces a
    decompression error when decompressing a nested compressed file
* Fri Nov  3 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.3.2:
  * double short option -%%%% enables both --files --bool (a single
  - %% still enables only --bool) for convenience
  * updated thread pool scheduling and execution with thread
    affinity and priority settings
  * improvements and fixes for minor (mostly cosmetic) issues
* Thu Oct 19 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.3.1:
  * Unicode 15.1 support
  * TUI features, including CTRL-Y improved viewer
  * TUI regex syntax highlighting with user-definable colors
* Sun Oct  8 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.3.0:
  * Redesigned TUI with a new split screen window pane to preview
    matching files
  * fix --zmax=n for n>1 that had a low chance to hang as
    discovered recently (about once in a few thousand runs) when
    searching (deeply) nested zip or tar archives
  * fix compressed file search of files that are exactly one byte
    long, instead of rejecting those files as being empty
* Sat Sep 23 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.2.0:
  * text user inerface improvements
  * improve recursive search performance
  * improve compatibility with GNU grep
  * improve detection of special devices to avoid searching them
* Mon Sep 18 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.1.0:
  * fix -Z fuzzy matching when character deletions are solely
    specified with a minus sign
  * fix --pager when a regex syntax error occurs
  * update --pager to use $PAGER
  * update --ignore-files for compliance with git and ag gitignore
    rules
  * update -Q TUI ctrl-S and ctrl-W to jump to context group
    separators when context options -ABC are specified
  * update -o for GNU grep compatibility with "empty-matching"
    patterns
  * update POSIX [[:space:]] and \s to exclude newline \n matching
  * improve performance: faster -c and line matching
  * improve performance: faster "empty-matching" pattern search
* Mon Aug 28 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.0.5:
  * Fix a recently-added optimization that may in some rare cases
    caused a problem with a match at the end of a file.
* Sat Aug 26 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.0.4:
  * update --save-config as per user request
  * correct an issue with -o and context
* Fri Aug 25 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.0.3:
  * new --delay=DELAY option to specify a default query TUI
    response delay time, which can be specified in a .ugrep config
    file with delay=DELAY (--save-config includes this setting also)
  * fix option -m compatibility issue wth GNU grep when showing
    context lines with -ABC after the last max match
* Wed Aug 23 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.0.2:
  * additional speed up with improved parametrization of the
    matching algorithm decision logic
* Sun Aug 20 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.0.1:
  * speed up option -l to search compressed files
  * enable an important search optimization that was no longer
    enabled
* Fri Aug 18 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.0.0:
  * faster async output, speeds up ugrep 3x when outputting many
    matching lines
  * removed "rest line" buffering, speeds up ugrep up to 2x,
    depending on the output-related options used
  * removed redundant "binary file" checking, speed-up 10%%~20%%
  * double size input buffer, speeds up searching 5%%~20%% when
    searching very large files (GB) with none/infrequent pattern
    matches
  * faster empty pattern matching, i.e. pattern '' matches all
    lines faster, as much as 10x faster
  * removed redundant color escape codes from the output
  * option -Q with an optional argument is now -Q=DELAY instead of
  - QDELAY, so -Q2 is -Q -2 (simple options should be composable/
    separable) which searches 2 directory levels deep with the
    query TUI
* Tue Aug 15 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.12.7:
  * compatibility improvement with one of GNU grep's idiosyncrasies:
    unpaired ) in regex are matched literally. This behavior is
    automatically in effect when the grep and egrep aliases of
    ugrep are used or explicitly with option -Y.
* Mon Aug  7 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.12.6:
  * New option -S (--dereference-files) to follow symbolic links
    only to files, not to directories, when using option -r for
    recursive search.
  * Updated default recursive search to strictly perform -r without
    following any symbolic links.
  * New option --index for fast index-based search with the new
    ugrep-indexer tool.
* Sat Aug  5 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.12.5:
  * New --iglob and --glob-ignore-case options
* Tue Jul 18 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.12.4:
  * Faster search for common search patterns, such as a set of
    words, using SIMD AVX and neon/AArch64 intrinsics
* Sat Jul 15 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.12.3:
  * Fixed a potential pattern match issue in the new v3.12
    optimizations
* Tue Jul 11 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.12.2:
  * Speed improvements to further speed up common search patterns
  * Improved man page
  * The ug and ug+ commands now enable --pretty by default
    (that is, if a .ugrep configuration file does not override it
    with no-pretty).
* Sun Jun  4 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- update to 3.12.1:
  * New ug+ and ugrep+ commands to search pdfs, documents and image
    metadata when the corresponding tools are installed
  * improved --filter option
  * speed improvements
* Sat Apr  8 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.11.2:
  * Improve --hyperlink with additional usability options
* Sun Apr  2 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.11.1:
  * Smarter interactive navigation in the TUI when option --tree is
    used with option -l or -c
* Sun Mar 19 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.11.0:
  * Update --format output when used with option -o to also enable
    option -u to show all matches automatically;
  * improve --json, --xml, --csv output when used with option -o
  * update option -o output with headings (when applicable) for
    every match like GNU grep
  * update options --format and --replace field %%m to output the
    number of matches sequentially
  * new --format and --replace field %%M outputs number of matching
    lines
* Sat Mar 18 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.10.1:
  * Fix a performace issue with specific regex patterns when used
    with case-insensitive pattern matching
* Wed Mar  1 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.10.0:
  * This release adds the option --tree to output directory trees
    of files for the options -l (--files-with-matches),
  - L (--files-withou-match), and -c (--count)
  * The option --pretty was updated to to enable --tree when output
    is sent to  a terminal. This can be disabled with --no-tree.
* Wed Feb  1 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.9.7:
  * handle gnutar archive extension field formats to search huge
    files (>4GB) stored in (gnu) tar archives
- includes changes gro 3.9.6:
  * Fixed a Unicode-specific regex pattern syntax issue that caused
    a valid regex pattern to produce a regex syntax error message
* Sun Jan 15 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.9.5:
  * Fix option -l (files-with-matches) when used with option -z
    (decompress) which would sometimes show duplicates when a
    compressed files had many matches
* Thu Jan  5 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.9.4:
  * fix spurious 0 byte in tar filename output results
  * fix support for PCRE2 prior 10.34
* Fri Dec 30 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.9.3:
  * Fix a PCRE2 library-related issues with -P (--perl-regexp)
    matching binary files
* Mon Aug 22 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.9.2:
  * Fixed an issue with invalid Unicode regex patterns
* Mon Aug 15 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.9.1:
  * make -r the default recursive search without following
    symlinked directories
  * Symlinked files are always searched on a search path, except
    with option -p (--no-dereference)
  * A fix for a minor issue with fuzzy matching when only allowing
    substitutions
* Wed Jun 29 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.8.3:
  * fix search with tiny lz4 files
  * skip empty zip files
* Sat Jun 11 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.8.2:
  * update documentation
* Tue Jun  7 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.8.1:
  * Fix bz2 issue cutting off decompression too soon
* Mon May 30 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.8.0
  * New option combination -o (--only-matching) with -ABC context
    for column context
  * option -o with -b or -k now shows results on separate lines
  * new option --width to truncate long lines to the specified
    width or the terminal width by default
  * short ug command now sorts by name by default
  * query TUI ALT-] [ (increase/decrease context) and ALT-} {
    (increase/decrease fuzziness) keys switched meaning
  * new %%+ format field used by updated --only-line-number option
* Wed May 11 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.7.11:
  * New -Zbest (--fuzzy=best) option argument best to only output
    the best matching patterns
* Tue May 10 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.7.10:
  * -Z (--fuzzy) can now be combined with -U (--binary) to fuzzy
    match bytes instead of Unicode characters
* Fri Apr  8 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.7.9:
  * Additional --stats results with total lines searched and
    matched, and time elapsed.
* Sat Apr  2 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.7.7:
  * New --hexdump options
  * --ignore-files improvement
  * speed improvements
  * New option --min-count
  * New complementary options --min-depth, --max-depth,
  - -min-line and --max-line which are added for consistency with
    the updated options --min-count and --max-count
  * Updated the --min-count option, which can now be combined with
    any other option except with -v (--invert-match)
  * Updated option -K (--range) to take a MAX argument instead of a
    FIRST argument for consistency with other min/max options
  * Recursive searching sysfd, such as /proc and /sys, no longer
    blocks on special files/devices
  * Fixed colorization of option -v when used with context options
  - A, -B and -C
  * Fixed option -r when combined with argument - (read standard
    input), which does both, like GNU grep
  * Updated --stats reporting and other minor improvements
* Fri Jan 28 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- update to 3.7.1:
  * add newline when showing usage and also fix segfault when arg == NULL
- update to 3.7.0:
  * README.md: add FreeBSD installation instructions
  * resolve LGTM alerts & minor improvements
  * Support "cpp" as a file type
  * msvc - Add matcher_avx2, matcher_avx512bw
- update to 3.6.0:
  * new option --replace & faster searching
* Thu Jan  6 2022 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.5.0:
  * New --zmax=NUM option to be used with -z (--decompress) to
    search compressed files and archives recursively stored within
    tar/zip/cpio/pax archives, e.g. to search tar and zip files
    stored in (compressed) tar files, in zip files etc. for up to
    NUM recursive levels deep. The --zmax argument may range from 1
    (default) to 99 for up to 99 decompression and de-archiving
    steps.
  * Improved option -U to be used for backward compatibility with
    GNU/BSD grep by no longer flagging invalid UTF as "binary
    files"
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 3.4.0:
  * New Boolean search query options --files and --lines.
    The specified Boolean search query conditions apply to
    lines by default.
    Because GNU/BSD grep and ugrep are generally line-based,
  - -lines is the default option.
    Specify --files --bool to apply the specified Boolean query
    to files as a whole: a file matches if all Boolean conditions
    are satisfied by matching patterns anywhere in the file
* Thu Jun 24 2021 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.3.4:
  * New --hyperlink option for terminals that support it
  * Revised and enhanced option -P (PCRE) compatible with GNU grep
  * Improved query UI option -Q with quick Tab/Shift/Tab navigation
  * CTRL-Y file viewing with --view to specify viewer
  * Improved CTRL-X/CTRL-R bookmarking to restore search state
  * Fix compatibility with GNU grep binary file search results
  * fix an optimization preventing unnecessary backtracking
  * performance improvement for option -P
* Thu May 13 2021 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.2.2:
  * Add support for file search on zstd-compressed files:
  - z (.zst, .zstd, .tzstd) and advanced .zipx method zstd (93)
* Sat May  1 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.1.15:
  * fix a recursive search crash
* Wed Apr 28 2021 Wang Jun <jgwang@suse.com>
- ugrep 3.1.14:
  * Fix names of the encodings, it's ISO-8859, not ISO-8869
  * Fixed an issue when placing options --bool, -G, -F, -w, -x
    at the end of the command line
  * Add missing header file "limits" in mmap.hpp
  * Use option `-U` instead of `-C` for `diff`
  * Minor --bool and --glob improvements; MinGW portability
  * Update README.md with Alpine Linux
  * Updated \s pattern matching to exclude newline, compatible with
    GNU/BSD grep.
  * Added format field %%[NAME]# to output named capturing groups and
    %%[NUM1|NAME1|NUM2|NAME2...]# to output the first capturing group
    that matched by num or name; option --bool improvements
  * Fix #125 and fix #122
* Tue Feb  9 2021 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.1.7:
  * various fixes, including fixes to globbing and regex
* Sun Jan 17 2021 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.1.3:
  * fixes for other platforms only
* Sun Dec 27 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.1.1:
  * clarifications on boolean search query pattern feature
* Fri Dec 18 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.1.0:
  * New --bool option to specify a Boolean search query pattern
  * New --and and --not options
  * --format not supports -v
* Mon Dec  7 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.0.6:
  * slightly improved error handling
* Thu Nov 26 2020 Wang Jun <jgwang@suse.com>
- ugrep 3.0.5:
  * 'enable-color' option deprecated, use 'disable-auto-color'
  * support wide Unicode strings
  * update some documents
* Sun Oct 25 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.0.4:
  * fix an issue with large zip files searched in the query UI
* Fri Oct 23 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 3.0.2:
  * speed improvements
* Tue Sep 22 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 2.5.6:
  * Interactive query UI usability improvements
  * new query UI commands:
    Alt-[ (decrease fuzziness by one),
    Alt-] (increase fuzziness by one),
    Alt-{ (decrease context size by one line),
    Alt-} (increase context size by one line)
* Thu Sep  3 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 2.5.5:
  * build improvements
  * workaround missing lz4 macro
  * updated Dockerfile
  * updated tests
* Thu Aug 20 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 2.5.3:
  * New --format option fields %%a (basename) and %%p (path)
  * fast incremental stdin search
  * updated --gitignore-files handling of negated globs
* Sun Aug 16 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 2.5.2:
  * Query UI monitor enhancements
* Tue Aug 11 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 2.5.1:
  * Query UI enhanced display updates; new option --not
* Tue Jul 28 2020 Martin Rey <mrey@suse.com>
- ugrep 2.5.0:
  * New query UI search commands: Tab to navigate into a directory
    or to select a single file to search; Shift-Tab to navigate up
    the directory tree or deselect the selected file. Press Ctrl-^
    to go back to the starting working directory. These commands
    are best experienced with option -l (Alt-l ("Alt-ell") in the
    query UI) to navigate directories in the list view.
  * Ctrl-S/Ctrl-W now also move down/up by directory in the query
    UI when viewing a list of files with options -l and -c.
  * Faster query UI response to commands (the response to patterns
    entered is still determined by the DELAY parameter.)
  * Option --pretty now also enables options -n and --sort in
    addition to --color, --heading, and -T when the output is sent
    to a terminal and if these options are not explicitly disabled
    or set already.
  * Fixed minor issues to improve the overall user experience
- ugrep 2.4.1:
  * Support lz4-compressed files with extension .lz4
* Sat Jul 11 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 2.4.0:
  * New ug command which is the same as ugrep --config with the new
  - -config option to use configuration files
  * new option --save-config to create configuration files
  * added --help [WHAT] for quick help on WHA
  * drop reproducible.patch, upstream
* Sun Jul  5 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Disable avx
- Add reproducible.patch to drop march=native
  to make package build reproducible (boo#1100677)
* Tue Jun 30 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 2.3.2:
  * gcc10 fixes and minor improvements
* Mon Jun 22 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 2.3.1:
  * Faster search context matching and display with new streaming
    implementation for options -A, -B, -C, and -y
  * including when combined with options -v, -W, and -X
  * remove the single-line search pattern constraint in prior
    versions for these options
  * fixed minor issue with option -G
* Sun Jun 14 2020 Andreas Stieger <andreas.stieger@gmx.de>
- ugrep 2.2.1:
  * improved query UI with Alt-g, corresponding to -g, --glob for
    interative globbing
  * improved fuzzy matching
* Sat Jun  6 2020 Andreas Stieger <andreas.stieger@gmx.de>
- initial package, 2.2.0
